Index: asterisk/apps/app_authenticate.c
===================================================================
RCS file: /usr/cvsroot/asterisk/apps/app_authenticate.c,v
retrieving revision 1.23
diff -u -r1.23 app_authenticate.c
--- asterisk/apps/app_authenticate.c	10 Nov 2005 20:56:45 -0000	1.23
+++ asterisk/apps/app_authenticate.c	22 Nov 2005 15:30:37 -0000
@@ -49,9 +49,9 @@
 static char *synopsis = "Authenticate a user";
 
 static char *descrip =
-"  Authenticate(password[|options]): This application asks the caller to enter a\n"
-"given password in order to continue dialplan execution. If the password begins\n"
-"with the '/' character, it is interpreted as a file which contains a list of\n"
+"  Authenticate(password[|options][|maxdigits]): This application asks the caller\n"
+"to enter a given password in order to continue dialplan execution. If the password\n"
+"begins with the '/' character, it is interpreted as a file which contains a list of\n"
 "valid passwords, listed 1 password per line in the file.\n"
 "  When using a database key, the value associated with the key can be anything.\n"
 "Users have three attempts to authenticate before the channel is hung up. If the\n"
@@ -66,6 +66,10 @@
 "         the file. When one of the passwords is matched, the channel will have\n"
 "         its account code set to the corresponding account code in the file.\n"
 "     r - Remove the database key upon successful entry (valid with 'd' only)\n"
+"     maxdigits  - maximum acceptable number of digits. Stops reading after\n"
+"         maxdigits have been entered (without requiring the user to\n"
+"         press the '#' key).\n"
+"         Defaults to 0 - no limit - wait for the user press the '#' key.\n"
 ;
 
 STANDARD_LOCAL_USER;
@@ -77,10 +81,12 @@
 	int res=0;
 	int jump = 0;
 	int retries;
+	int maxdigits;
 	struct localuser *u;
 	char password[256]="";
 	char passwd[256];
 	char *opts;
+	char *tmp;
 	char *prompt;
 	
 	if (ast_strlen_zero(data)) {
@@ -107,10 +113,27 @@
 		opts = "";
 	if (strchr(opts, 'j'))
 		jump = 1;
+	tmp = strchr(opts, '|');
+	if (tmp) {
+		*tmp = 0;
+		tmp++;
+		maxdigits = strtol(tmp, NULL, 10);
+		if ((maxdigits<1) || (maxdigits>sizeof(passwd)-2))
+                        maxdigits = sizeof(passwd) - 2;
+	} else {
+		maxdigits = sizeof(passwd) - 2;
+	}
+	if(!maxdigits) {
+		/* In case when 0 supplied */
+		maxdigits = sizeof(passwd) - 2;
+	}
+	if(option_debug > 2) {
+		ast_log(LOG_DEBUG, "Accepting a maximum of %d digits.\n", maxdigits);
+	}
 	/* Start asking for password */
 	prompt = "agent-pass";
 	for (retries = 0; retries < 3; retries++) {
-		res = ast_app_getdata(chan, prompt, passwd, sizeof(passwd) - 2, 0);
+		res = ast_app_getdata(chan, prompt, passwd, maxdigits, 0);
 		if (res < 0)
 			break;
 		res = 0;
